==> CustomDiagramIcons-0.1.3.tar.gz: CustomDiagramIcons-0.1.3/CustomDiagramIcons/module1.py <==
from diagrams import Diagram
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeploy
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployPipeline
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployServerNode
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerNode
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerPool
from CustomDiagramIcons.onprem.cd.octopusDeploy import octpusDeployRelease
from CustomDiagramIcons.generic import softwareEngineer
from CustomDiagramIcons.generic import JIRA
from CustomDiagramIcons.generic import CRIM
from CustomDiagramIcons.generic import GitHub
from CustomDiagramIcons.generic import CRIMTools
from CustomDiagramIcons.generic import ReportPortal

def octopusDeploy_icon(val):
    return octopusDeploy(val)

def octopusDeployPipeline_icon(val):
    return octopusDeployPipeline(val)

def octopusDeployServerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerPool_icon(val):
    return octopusDeployServerNode(val)

def octpusDeployRelease_icon(val):
    return octpusDeployRelease(val)

def softwareEngineer_icon(val):
    return softwareEngineer(val)

def JIRA_icon(val):
    return JIRA(val)

def CRIM_icon(val):
    return CRIM(val)

def GitHub_icon(val):
    return GitHub(val)

def CRIMTools_icon(val):
    return CRIMTools(val)

def ReportPortal_icon(val):
    return ReportPortal(val)

==> CustomDiagramIcons-0.1.5.tar.gz: CustomDiagramIcons-0.1.5/CustomDiagramIcons/module1.py <==
from diagrams import Diagram
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployProgram
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployPipeline
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployServerNode
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerNode
from CustomDiagramIcons.onprem.cd.octopusDeploy import octopusDeployWorkerPool
from CustomDiagramIcons.onprem.cd.octopusDeploy import octpusDeployRelease
from CustomDiagramIcons.generic import softwareEngineer
from CustomDiagramIcons.generic import JIRA
from CustomDiagramIcons.generic import CRIM
from CustomDiagramIcons.generic import GitHub
from CustomDiagramIcons.generic import CRIMTools
from CustomDiagramIcons.generic import ReportPortal

def octopusDeploy_icon(val):
    return octopusDeployProgram(val)

def octopusDeployPipeline_icon(val):
    return octopusDeployPipeline(val)

def octopusDeployServerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerNode_icon(val):
    return octopusDeployServerNode(val)

def octopusDeployWorkerPool_icon(val):
    return octopusDeployServerNode(val)

def octpusDeployRelease_icon(val):
    return octpusDeployRelease(val)

def softwareEngineer_icon(val):
    return softwareEngineer(val)

def JIRA_icon(val):
    return JIRA(val)

def CRIM_icon(val):
    return CRIM(val)

def GitHub_icon(val):
    return GitHub(val)

def CRIMTools_icon(val):
    return CRIMTools(val)

def ReportPortal_icon(val):
    return ReportPortal(val)
